Struct Cfgr
#[repr(transparent)]pub struct Cfgr(pub u32);Expand description
Configuration register
Tuple Fields
0: u32Implementations
impl Cfgr
impl Cfgr
pub const fn set_extsel(&mut self, val: u8)
pub const fn set_extsel(&mut self, val: u8)
External trigger selection for regular group
pub const fn exten(&self) -> Exten
pub const fn exten(&self) -> Exten
External trigger enable and polarity selection for regular channels
pub const fn set_exten(&mut self, val: Exten)
pub const fn set_exten(&mut self, val: Exten)
External trigger enable and polarity selection for regular channels
pub const fn ovrmod(&self) -> bool
pub const fn ovrmod(&self) -> bool
Overrun mode (0: ADC_DR is preserved when an overrun is detected, 1: ADC_DR is overwritten with the last conversion result)
pub const fn set_ovrmod(&mut self, val: bool)
pub const fn set_ovrmod(&mut self, val: bool)
Overrun mode (0: ADC_DR is preserved when an overrun is detected, 1: ADC_DR is overwritten with the last conversion result)
pub const fn set_autdly(&mut self, val: bool)
pub const fn set_autdly(&mut self, val: bool)
Delayed conversion mode
pub const fn set_discen(&mut self, val: bool)
pub const fn set_discen(&mut self, val: bool)
Discontinuous mode for regular channels
pub const fn set_discnum(&mut self, val: u8)
pub const fn set_discnum(&mut self, val: u8)
Discontinuous mode channel count
pub const fn set_jdiscen(&mut self, val: bool)
pub const fn set_jdiscen(&mut self, val: bool)
Discontinuous mode on injected channels
pub const fn awd1sgl(&self) -> bool
pub const fn awd1sgl(&self) -> bool
Enable the analog watchdog 1 on a single channel (1) or on all channels (0)
pub const fn set_awd1sgl(&mut self, val: bool)
pub const fn set_awd1sgl(&mut self, val: bool)
Enable the analog watchdog 1 on a single channel (1) or on all channels (0)
pub const fn set_awd1en(&mut self, val: bool)
pub const fn set_awd1en(&mut self, val: bool)
Analog watchdog 1 enable on regular channels
pub const fn set_jawd1en(&mut self, val: bool)
pub const fn set_jawd1en(&mut self, val: bool)
Analog watchdog 1 enable on injected channels
pub const fn set_awd1ch(&mut self, val: u8)
pub const fn set_awd1ch(&mut self, val: u8)
Analog watchdog 1 channel selection